import { Enum, Model, ModelProperty, Program, Union } from "@typespec/compiler";
import { ArmCommonDefinitionDecorator, ArmCommonParameterDecorator, ArmCommonTypesVersionsDecorator } from "../generated-defs/Azure.ResourceManager.CommonTypes.Private.js";
export declare const namespace = "Azure.ResourceManager.CommonTypes.Private";
export declare const ArmCommonTypesDefaultVersion = "v3";
export interface ArmCommonTypeRecord {
    name: string;
    kind: "definitions" | "parameters";
    version: string;
    basePath: string;
    referenceFile?: string;
}
export interface ArmCommonTypeRecords {
    records: {
        [key: string]: ArmCommonTypeRecord;
    };
    defaultKey?: string;
}
export declare function getCommonTypeRecords(program: Program, entity: Model | ModelProperty | Enum | Union): ArmCommonTypeRecords;
/**
 * Refer an model property to be a common ARM parameter
 * @param {DecoratorContext} context DecoratorContext object
 * @param {Type} entity Decorator target type. Must be `Model`
 * @param {string?} definitionName Optional definition name
 * @param {string?} version Optional version
 * @param {string?} referenceFile Optional common file path
 * @returns void
 */
export declare const $armCommonParameter: ArmCommonParameterDecorator;
/**
 * Using ARM common definition for a Model
 * @param {DecoratorContext} context DecoratorContext object
 * @param {Type} entity Decorator target type. Must be `Model`
 * @param {string?} definitionName Optional definition name
 * @param {string?} version Optional version
 * @param {string?} referenceFile Optional common file path
 * @returns {void}
 */
export declare const $armCommonDefinition: ArmCommonDefinitionDecorator;
/**
 * Specify the ARM commont type version reference for a particular spec version or namespace.
 * @param DecoratorContext context DecoratorContext object
 * @param enumType entity Decorator target type. Must be `Model`
 * @returns void
 */
export declare const $armCommonTypesVersions: ArmCommonTypesVersionsDecorator;
//# sourceMappingURL=commontypes.private.decorators.d.ts.map